@@ -1,25 +1,26 @@
-/* This file is part of the KDE libraries
-   Copyright (c) 2000 Waldo Bastian <bastian@kde.org>
-   Copyright (C) 2002-2004 Christoph Cullmann <cullmann@kde.org>
+/*  SPDX-License-Identifier: LGPL-2.0-or-later
 
-   This library is free software; you can redistribute it and/or
-   modify it under the terms of the GNU Library General Public
-   License as published by the Free Software Foundation; either
-   version 2 of the License, or (at your option) any later version.
+    Copyright (c) 2000 Waldo Bastian <bastian@kde.org>
+    Copyright (C) 2002-2004 Christoph Cullmann <cullmann@kde.org>
 
-   This library is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-   Library General Public License for more details.
+    This library is free software; you can redistribute it and/or
+    modify it under the terms of the GNU Library General Public
+    License as published by the Free Software Foundation; either
+    version 2 of the License, or (at your option) any later version.
 
-   You should have received a copy of the GNU Library General Public License
-   along with this library; see the file COPYING.LIB.  If not, write to
-   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-   Boston, MA 02110-1301, USA.
+    This library is distributed in the hope that it will be useful,
+    but WITHOUT ANY WARRANTY; without even the implied warranty of
+    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+    Library General Public License for more details.
+
+    You should have received a copy of the GNU Library General Public License
+    along with this library; see the file COPYING.LIB.  If not, write to
+    the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+    Boston, MA 02110-1301, USA.
 */
 
-#ifndef __KATE_BUFFER_H__
-#define __KATE_BUFFER_H__
+#ifndef KATE_BUFFER_H
+#define KATE_BUFFER_H
 
 #include "katetextbuffer.h"
 
@@ -28,7 +29,10 @@
 #include <QObject>
 
 class KateLineInfo;
-namespace KTextEditor { class DocumentPrivate; }
+namespace KTextEditor
+{
+class DocumentPrivate;
+}
 class KateHighlighting;
 
 /**
@@ -51,7 +55,7 @@ public:
     /**
      * Goodbye buffer
      */
-    ~KateBuffer() Q_DECL_OVERRIDE;
+    ~KateBuffer() override;
 
 public:
     /**
@@ -105,7 +109,7 @@ public:
     /**
      * Clear the buffer.
      */
-    void clear() Q_DECL_OVERRIDE;
+    void clear() override;
 
     /**
      * Open a file, use the given filename
@@ -189,13 +193,13 @@ public:
      * Unwrap given line.
      * @param line line to unwrap
      */
-    void unwrapLine(int line) Q_DECL_OVERRIDE;
+    void unwrapLine(int line) override;
 
     /**
      * Wrap line at given cursor position.
      * @param position line/column as cursor where to wrap
      */
-    void wrapLine(const KTextEditor::Cursor &position) Q_DECL_OVERRIDE;
+    void wrapLine(const KTextEditor::Cursor &position) override;
 
 public:
     inline int tabWidth() const
@@ -228,7 +232,8 @@ public:
      * For a given line, compute the folding range that starts there
      * to be used to fold e.g. from the icon border
      * @param startLine start line
-     * @return folding range starting at the given line or invalid range
+     * @return folding range starting at the given line or invalid range when
+     *         there is no folding start or @p startLine is not valid
      */
     KTextEditor::Range computeFoldingRangeForStartLine(int startLine);
 
@@ -291,4 +296,3 @@ private:
 };
 
 #endif
-
