@@ -1,33 +1,33 @@
-/* This file is part of the KDE libraries
-   Copyright (C) 2007-2008 David Nolden <david.nolden.kdevelop@art-master.de>
-   Copyright (C) 2005-2006 Hamish Rodda <rodda@kde.org>
- *
- *  This library is free software; you can redistribute it and/or
- *  modify it under the terms of the GNU Library General Public
- *  License as published by the Free Software Foundation; either
- *  version 2 of the License, or (at your option) any later version.
- *
- *  This library is distributed in the hope that it will be useful,
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- *  Library General Public License for more details.
- *
- *  You should have received a copy of the GNU Library General Public License
- *  along with this library; see the file COPYING.LIB.  If not, write to
- *  the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
- *  Boston, MA 02110-1301, USA.
- */
+/*  SPDX-License-Identifier: LGPL-2.0-or-later
+
+    Copyright (C) 2007-2008 David Nolden <david.nolden.kdevelop@art-master.de>
+    Copyright (C) 2005-2006 Hamish Rodda <rodda@kde.org>
+
+    This library is free software; you can redistribute it and/or
+    modify it under the terms of the GNU Library General Public
+    License as published by the Free Software Foundation; either
+    version 2 of the License, or (at your option) any later version.
+
+    This library is distributed in the hope that it will be useful,
+    but WITHOUT ANY WARRANTY; without even the implied warranty of
+    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+    Library General Public License for more details.
+
+    You should have received a copy of the GNU Library General Public License
+    along with this library; see the file COPYING.LIB.  If not, write to
+    the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+    Boston, MA 02110-1301, USA.
+*/
 
 #ifndef KTEXTEDITOR_CODECOMPLETIONMODEL_H
 #define KTEXTEDITOR_CODECOMPLETIONMODEL_H
 
-#include <ktexteditor_export.h>
 #include <QModelIndex>
 #include <ktexteditor/range.h>
+#include <ktexteditor_export.h>
 
 namespace KTextEditor
 {
-
 class Document;
 class View;
 
@@ -82,7 +82,7 @@ class KTEXTEDITOR_EXPORT CodeCompletionModel : public QAbstractItemModel
 
 public:
     explicit CodeCompletionModel(QObject *parent);
-    ~CodeCompletionModel() Q_DECL_OVERRIDE;
+    ~CodeCompletionModel() override;
 
     enum Columns {
         Prefix = 0,
@@ -97,53 +97,53 @@ public:
     };
     static const int ColumnCount = Postfix + 1;
 
+    /// @see CompletionProperties
     enum CompletionProperty {
-        NoProperty  = 0x0,
+        NoProperty = 0x0,
         FirstProperty = 0x1,
 
         // Access specifiers - no more than 1 per item
-        Public      = 0x1,
-        Protected   = 0x2,
-        Private     = 0x4,
+        Public = 0x1,
+        Protected = 0x2,
+        Private = 0x4,
 
         // Extra access specifiers - any number per item
-        Static      = 0x8,
-        Const       = 0x10,
+        Static = 0x8,
+        Const = 0x10,
 
         // Type - no more than 1 per item (except for Template)
-        Namespace   = 0x20,
-        Class       = 0x40,
-        Struct      = 0x80,
-        Union       = 0x100,
-        Function    = 0x200,
-        Variable    = 0x400,
-        Enum        = 0x800,
-        Template    = 0x1000,
-        TypeAlias   = 0x2000,
+        Namespace = 0x20,
+        Class = 0x40,
+        Struct = 0x80,
+        Union = 0x100,
+        Function = 0x200,
+        Variable = 0x400,
+        Enum = 0x800,
+        Template = 0x1000,
+        TypeAlias = 0x2000,
 
         // Special attributes - any number per item
-        Virtual     = 0x4000,
-        Override    = 0x8000,
-        Inline      = 0x10000,
-        Friend      = 0x20000,
-        Signal      = 0x40000,
-        Slot        = 0x80000,
+        Virtual = 0x4000,
+        Override = 0x8000,
+        Inline = 0x10000,
+        Friend = 0x20000,
+        Signal = 0x40000,
+        Slot = 0x80000,
 
         // Scope - no more than 1 per item
-        LocalScope      = 0x100000,
-        NamespaceScope  = 0x200000,
-        GlobalScope     = 0x400000,
+        LocalScope = 0x100000,
+        NamespaceScope = 0x200000,
+        GlobalScope = 0x400000,
 
         // Keep this in sync so the code knows when to stop
-        LastProperty    = GlobalScope
+        LastProperty = GlobalScope
     };
+    /// Stores a combination of #CompletionProperty values.
     Q_DECLARE_FLAGS(CompletionProperties, CompletionProperty)
 
-    enum HighlightMethod {
-        NoHighlighting        = 0x0,
-        InternalHighlighting  = 0x1,
-        CustomHighlighting    = 0x2
-    };
+    /// @see HighlightMethods
+    enum HighlightMethod { NoHighlighting = 0x0, InternalHighlighting = 0x1, CustomHighlighting = 0x2 };
+    /// Stores a combination of #HighlightMethod values.
     Q_DECLARE_FLAGS(HighlightMethods, HighlightMethod)
 
     /// Meta information is passed through extra {Qt::ItemDataRole}s.
@@ -282,7 +282,7 @@ public:
          * Suffix: ", int param2)"
          *
          * If you don't use the highlighting, matching, etc. you can also return the columns in the usual way.
-        * */
+         * */
         ArgumentHintDepth,
 
         /**
@@ -346,7 +346,7 @@ public:
          *
          * This role can also be used to define completely custom groups, bypassing the editors builtin grouping:
          *  - Return Qt::DisplayRole when GroupRole is requested
-         *  - Return the lable text of the group when Qt::DisplayRole
+         *  - Return the label text of the group when Qt::DisplayRole
          *   - Optional: Return an integer sorting-value when InheritanceDepth is  requested. This number will
          *               be used to determine the order of the groups. The order of the builtin groups is:
          *               1 = Best Matches, 100 = Local Scope, 200 = Public, 300 = Protected, 400 = Private, 500 = Namespace, 600 = Global
@@ -364,11 +364,7 @@ public:
 
     void setRowCount(int rowCount);
 
-    enum InvocationType {
-        AutomaticInvocation,
-        UserInvocation,
-        ManualInvocation
-    };
+    enum InvocationType { AutomaticInvocation, UserInvocation, ManualInvocation };
 
     /**
      * This function is responsible to generating / updating the list of current
@@ -384,15 +380,15 @@ public:
     virtual void completionInvoked(KTextEditor::View *view, const KTextEditor::Range &range, InvocationType invocationType);
 
     /**
-      * This function is responsible for inserting a selected completion into the
-      * view. The default implementation replaces the text that the completions
-      * were based on with the Qt::DisplayRole of the Name column of the given match.
-      *
-      * @param view the view to insert the completion into
-      * @param word the Range that the completions are based on (what the user entered
-      * so far)
-      * @param index identifies the completion match to insert
-      * */
+     * This function is responsible for inserting a selected completion into the
+     * view. The default implementation replaces the text that the completions
+     * were based on with the Qt::DisplayRole of the Name column of the given match.
+     *
+     * @param view the view to insert the completion into
+     * @param word the Range that the completions are based on (what the user entered
+     * so far)
+     * @param index identifies the completion match to insert
+     * */
     virtual void executeCompletionItem(KTextEditor::View *view, const Range &word, const QModelIndex &index) const;
 
     // Reimplementations
@@ -400,32 +396,32 @@ public:
      * Reimplemented from QAbstractItemModel::columnCount(). The default implementation
      * returns ColumnCount for all indices.
      * */
-    int columnCount(const QModelIndex &parent = QModelIndex()) const Q_DECL_OVERRIDE;
+    int columnCount(const QModelIndex &parent = QModelIndex()) const override;
     /**
      * Reimplemented from QAbstractItemModel::index(). The default implementation
      * returns a standard QModelIndex as long as the row and column are valid.
      * */
-    QModelIndex index(int row, int column, const QModelIndex &parent = QModelIndex()) const Q_DECL_OVERRIDE;
+    QModelIndex index(int row, int column, const QModelIndex &parent = QModelIndex()) const override;
     /**
      * Reimplemented from QAbstractItemModel::itemData(). The default implementation
      * returns a map with the QAbstractItemModel::data() for all roles that are used
      * by the CodeCompletionInterface. You will need to reimplement either this
      * function or QAbstractItemModel::data() in your CodeCompletionModel.
      * */
-    QMap<int, QVariant> itemData(const QModelIndex &index) const Q_DECL_OVERRIDE;
+    QMap<int, QVariant> itemData(const QModelIndex &index) const override;
     /**
      * Reimplemented from QAbstractItemModel::parent(). The default implementation
      * returns an invalid QModelIndex for all items. This is appropriate for
      * non-hierarchical / flat lists of completions.
      * */
-    QModelIndex parent(const QModelIndex &index) const Q_DECL_OVERRIDE;
+    QModelIndex parent(const QModelIndex &index) const override;
     /**
      * Reimplemented from QAbstractItemModel::rowCount(). The default implementation
      * returns the value set by setRowCount() for invalid (toplevel) indices, and 0
      * for all other indices. This is appropriate for non-hierarchical / flat lists
      * of completions
      * */
-    int rowCount(const QModelIndex &parent = QModelIndex()) const Q_DECL_OVERRIDE;
+    int rowCount(const QModelIndex &parent = QModelIndex()) const override;
 
     /**
      * This function returns true if the model needs grouping, otherwise false.
