@@ -1,21 +1,22 @@
-/* This file is part of the KDE libraries
-   Copyright (C) 2001-2014 Christoph Cullmann <cullmann@kde.org>
-   Copyright (C) 2005-2014 Dominik Haumann (dhaumann@kde.org)
+/*  SPDX-License-Identifier: LGPL-2.0-or-later
 
-   This library is free software; you can redistribute it and/or
-   modify it under the terms of the GNU Library General Public
-   License as published by the Free Software Foundation; either
-   version 2 of the License, or (at your option) any later version.
+    Copyright (C) 2001-2014 Christoph Cullmann <cullmann@kde.org>
+    Copyright (C) 2005-2014 Dominik Haumann (dhaumann@kde.org)
 
-   This library is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-   Library General Public License for more details.
+    This library is free software; you can redistribute it and/or
+    modify it under the terms of the GNU Library General Public
+    License as published by the Free Software Foundation; either
+    version 2 of the License, or (at your option) any later version.
 
-   You should have received a copy of the GNU Library General Public License
-   along with this library; see the file COPYING.LIB.  If not, write to
-   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-   Boston, MA 02110-1301, USA.
+    This library is distributed in the hope that it will be useful,
+    but WITHOUT ANY WARRANTY; without even the implied warranty of
+    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+    Library General Public License for more details.
+
+    You should have received a copy of the GNU Library General Public License
+    along with this library; see the file COPYING.LIB.  If not, write to
+    the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+    Boston, MA 02110-1301, USA.
 */
 
 #ifndef KTEXTEDITOR_DOCUMENT_H
@@ -38,13 +39,44 @@ class KConfigGroup;
 
 namespace KTextEditor
 {
-
 class DocumentPrivate;
 class EditingTransactionPrivate;
 class MainWindow;
 class Message;
 class View;
 
+/**
+ * \brief Search flags for use with searchText.
+ *
+ * Modifies the behavior of searchText.
+ * By default it is searched for a case-sensitive plaintext pattern,
+ * without processing of escape sequences, with "whole words" off,
+ * in forward direction, within a non-block-mode text range.
+ *
+ * \see SearchOptions
+ * \author Sebastian Pipping \<webmaster@hartwork.org\>
+ */
+enum SearchOption {
+    Default = 0, ///< Default settings
+
+    // modes
+    Regex = 1 << 1, ///< Treats the pattern as a regular expression
+
+    // options for all modes
+    CaseInsensitive = 1 << 4, ///< Ignores cases, e.g. "a" matches "A"
+    Backwards = 1 << 5,       ///< Searches in backward direction
+
+    // options for plaintext
+    EscapeSequences = 1 << 10, ///< Plaintext mode: Processes escape sequences
+    WholeWords = 1 << 11,      ///< Plaintext mode: Whole words only, e.g. @em not &quot;amp&quot; in &quot;example&quot;
+
+    MaxSearchOption = 1 << 31 ///< Placeholder for binary compatibility
+};
+
+/// Stores a combination of #SearchOption values.
+Q_DECLARE_FLAGS(SearchOptions, SearchOption)
+Q_DECLARE_OPERATORS_FOR_FLAGS(SearchOptions)
+
 /**
  * \brief A KParts derived class representing a text document.
  *
@@ -93,7 +125,7 @@ class View;
  * textChanged() are emitted. Whether an editing transaction is currently active
  * can be checked by calling isEditingTransactionRunning().
  *
- * @note The signal editingFinished() is always emitted when the last istance
+ * @note The signal editingFinished() is always emitted when the last instance
  *       of EditingTransaction is destroyed. Contrary, the signal textChanged()
  *       is emitted only if text changed. Hence, textChanged() is more accurate
  *       with respect to changes in the Document.
@@ -242,12 +274,16 @@ public:
     virtual QString mimeType() = 0;
 
     /**
-     * Get the md5 checksum of the Document's contents on disk.
-     * The returned md5sum equals the md5sum of the file written to disk.
+     * Get the git hash of the Document's contents on disk.
+     * The returned hash equals the git hash of the file written to disk.
      * If the document is a remote document, the checksum may not be
      * available. In this case, QByteArray::isNull() returns \e true.
      *
-     * \return the md5 checksum of the document
+     * git hash is defined as:
+     *
+     * sha1("blob " + filesize + "\0" + filecontent)
+     *
+     * \return the git hash of the document
      */
     virtual QByteArray checksum() const = 0;
 
@@ -359,9 +395,11 @@ public:
     bool openingError() const;
 
     /**
-     * Error message if any problem occured on last load.
+     * Error message if any problem occurred on last load.
      * @return error message what went wrong on loading
      */
+    // TODO KF6: Not needed anymore since we show load trouble as KTextEditor::Message.
+    //      Remove all code which set m_openingErrorMessage
     QString openingErrorMessage() const;
 
     /*
@@ -443,51 +481,52 @@ public:
      *
      * @see editingStarted(), editingFinished()
      */
-    class KTEXTEDITOR_EXPORT EditingTransaction {
-        public:
-            /**
-             * Constructs the object and starts an editing transaction by
-             * calling start().
-             *
-             * @param document document for the transaction
-             * @see start()
-             */
-            explicit EditingTransaction(Document *document);
+    class KTEXTEDITOR_EXPORT EditingTransaction
+    {
+    public:
+        /**
+         * Constructs the object and starts an editing transaction by
+         * calling start().
+         *
+         * @param document document for the transaction
+         * @see start()
+         */
+        explicit EditingTransaction(Document *document);
 
-            /**
-             * Destructs the object and, if needed, finishs a running editing
-             * transaction by calling finish().
-             *
-             * @see finish()
-             */
-            ~EditingTransaction();
+        /**
+         * Destructs the object and, if needed, finishes a running editing
+         * transaction by calling finish().
+         *
+         * @see finish()
+         */
+        ~EditingTransaction();
 
-            /**
-             * By calling start(), the editing transaction can be started again.
-             * This function only is of use in combination with finish().
-             *
-             * @see finish()
-             */
-            void start();
+        /**
+         * By calling start(), the editing transaction can be started again.
+         * This function only is of use in combination with finish().
+         *
+         * @see finish()
+         */
+        void start();
 
-            /**
-             * By calling finish(), the editing transaction can be finished
-             * already before destruction of this instance.
-             *
-             * @see start()
-             */
-            void finish();
+        /**
+         * By calling finish(), the editing transaction can be finished
+         * already before destruction of this instance.
+         *
+         * @see start()
+         */
+        void finish();
 
-        private:
-            /**
-             * no copying allowed
-             */
-            Q_DISABLE_COPY(EditingTransaction)
+    private:
+        /**
+         * no copying allowed
+         */
+        Q_DISABLE_COPY(EditingTransaction)
 
-            /**
-             * private d-pointer
-             */
-            EditingTransactionPrivate *const d;
+        /**
+         * private d-pointer
+         */
+        EditingTransactionPrivate *const d;
     };
 
     /**
@@ -575,7 +614,7 @@ public:
      *
      * \since 5.0
      */
-    virtual bool isValidTextPosition(const KTextEditor::Cursor& cursor) const = 0;
+    virtual bool isValidTextPosition(const KTextEditor::Cursor &cursor) const = 0;
 
     /**
      * Get the document content within the given \p range.
@@ -649,7 +688,8 @@ public:
      * A Range which encompasses the whole document.
      * \return A range from the start to the end of the document
      */
-    inline Range documentRange() const {
+    inline Range documentRange() const
+    {
         return Range(Cursor::start(), documentEnd());
     }
 
@@ -680,7 +720,8 @@ public:
      * \param line line
      * \see lineLength(), line()
      */
-    inline Cursor endOfLine(int line) const {
+    inline Cursor endOfLine(int line) const
+    {
         return Cursor(line, lineLength(line));
     }
 
@@ -792,6 +833,29 @@ public:
      */
     virtual bool removeLine(int line) = 0;
 
+    /**
+     * \brief Searches the given input range for a text pattern.
+     *
+     * Searches for a text pattern within the given input range.
+     * The kind of search performed depends on the \p options
+     * used. Use this function for plaintext searches as well as
+     * regular expression searches. If no match is found the first
+     * (and only) element in the vector return is the invalid range.
+     * When searching for regular expressions, the first element holds
+     * the range of the full match, the subsequent elements hold
+     * the ranges of the capturing parentheses.
+     *
+     * \param range    Input range to search in
+     * \param pattern  Text pattern to search for
+     * \param options  Combination of search flags
+     * \return         List of ranges (length >=1)
+     *
+     * \author Sebastian Pipping \<webmaster@hartwork.org\>
+     *
+     * \since 5.11
+     */
+    QVector<KTextEditor::Range> searchText(const KTextEditor::Range &range, const QString &pattern, const SearchOptions options = Default) const;
+
     /*
      * SIGNALS
      * Following signals should be emitted by the document if the text content
@@ -858,7 +922,7 @@ Q_SIGNALS:
 
     /**
      * \name Highlighting and Related Information
-     * 
+     *
      * \{
      */
 public:
@@ -1047,7 +1111,7 @@ public:
 public:
     /**
      * Read session settings from the given \p config.
-     * 
+     *
      * Known flags:
      * - \p SkipUrl => do not save/restore the file
      * - \p SkipMode => do not save/restore the mode
@@ -1118,4 +1182,3 @@ private:
 Q_DECLARE_METATYPE(KTextEditor::Document *)
 
 #endif
-
